@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 """ Stanley Flat File Blog Tool
     ---------------------------
     author: Glen Swinfield <glen.swinfied@gmail.com>
@@ -83,7 +84,7 @@ class Jinja2Compiler(Compiler):
             data.update({'posts': contentfilter})
             compiled_content = template_obj.render(data)
             with open(dst_file, 'w+') as dst:
-                dst.write(compiled_content)
+                dst.write(compiled_content.encode('ascii', 'xmlcharrefreplace'))
                 built.append(content.filename)
 
         for noncontent in noncontents:
